@@ -21,6 +21,7 @@ from datetime import datetime, timedelta
 import hashlib
 
 from napoleontoolbox.connector import napoleon_connector
+from napoleontoolbox.bot import binance_bot
 
 def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_signal=True, compute_parallel = False):
     high_dict = fetcher.pair_dict['high']
@@ -73,14 +74,17 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
 
             if compute_day_signal:
                 if compute_parallel:
-                    fetcher.launchDayParallelPool()
+                    ia_day_signal = fetcher.launchDayParallelPool()
                 else:
-                    fetcher.launchDaySequential()
+                    ia_day_signal = fetcher.launchDaySequential()
 
             if (len(fetcher.day_np.shape) > 1 and len(fetcher.day_np) > 3):
                 print('last three days')
                 print(fetcher.day_np[-3:, :])
 
+            print('day ia new signal computation for the bot ' + str(ia_day_signal))
+            fetcher.bot.update_position(fetcher.pair, ia_day_signal)
+
             if fetcher.hour_np is not None and len(fetcher.hour_np)>0:
                 print('persisting hours dataframe for the previous day')
                 #fetcher.upload_last_hour_60_minutes_dataframe()
@@ -184,12 +188,13 @@ def pair_handling_message(fetcher, msg, compute_minute_signal=True, compute_day_
                 fetcher.minute_np = np.vstack((fetcher.minute_np, new_data))
             if compute_minute_signal:
                 if compute_parallel:
-                    fetcher.launchMinuteParallelPool()
+                    ia_minute_signal = fetcher.launchMinuteParallelPool()
                 else:
-                    fetcher.launchMinuteSequential()
+                    ia_minute_signal = fetcher.launchMinuteSequential()
             if (len(fetcher.minute_np.shape)>1 and len(fetcher.minute_np)>3):
-                print('last three minutes')
+                print('last three minutes '+minute_name)
                 print(fetcher.minute_np[-3:,:])
+                print('minute ia signal ' + str(ia_minute_signal))
             #fetcher.minute_df.loc[len(fetcher.minute_df)] = new_data
         # we clear every former minutes
         high_dict.clear()
@@ -220,6 +225,8 @@ class RealTimeSignalEnsemblingParalleLauncher():
         self.BINANCE_PUBLIC = BINANCE_PUBLIC
         self.BINANCE_SECRET = BINANCE_SECRET
 
+        self.bot = binance_bot.NaPoleonBinanceFutureBot(BINANCE_PUBLIC, BINANCE_SECRET)
+
         self.dropbox_backup =dropbox_backup
         self.drop_token =drop_token
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
@@ -639,7 +646,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
 
     def upload_last_day_24_hours_signals_dataframe(self):
         print('updating 24 hours day df')
-        updated_df=pd.DataFrame(data=self.hour_np, columns = self.generic_columns, index=range(len(self.minute_signal_np)))
+        updated_df=pd.DataFrame(data=self.hour_np, columns = self.generic_columns, index=range(len(self.hour_np)))
         # updated_df = updated_df.astype(
         #     {'ts': 'float64', 'open': 'float64', 'high': 'float64', 'low': 'float64', 'close': 'float64','volumefrom': 'float64'}
         #                                )
@@ -788,8 +795,13 @@ class RealTimeSignalEnsemblingParalleLauncher():
                     for row_idx in range(1, self.day_signal_np.shape[0]):
                         if np.isnan(self.day_signal_np[row_idx, signal_counter]):
                             self.day_signal_np[row_idx, signal_counter] = self.day_signal_np[row_idx-1, signal_counter]
+                else :
+                    if np.isnan(self.day_signal_np[-1, signal_counter]):
+                        self.day_signal_np[-1, signal_counter] = 0
                 counter = counter + 1
-
+            last_signals = self.day_signal_np[-1, len(self.generic_columns) :]
+            return self.day_signals_ia_mixing(last_signals)
+        return np.nan
 
     def launchMinuteParallelPool(self, use_num_cpu):
         self.update_minute_dataframe()
@@ -831,12 +843,29 @@ class RealTimeSignalEnsemblingParalleLauncher():
             counter = 0
             for meArg in self.min_calib_signals_list:
                 triggered = trigger_results[counter]
+                signal_counter = len(self.generic_columns) + counter
                 if triggered:
-                    signal_counter = len(self.generic_columns)+counter
                     for row_idx in range(1, self.minute_signal_np.shape[0]):
                         if np.isnan(self.minute_signal_np[row_idx, signal_counter]):
                             self.minute_signal_np[row_idx, signal_counter] = self.minute_signal_np[row_idx-1, signal_counter]
+                else :
+                    if np.isnan(self.minute_signal_np[-1, signal_counter]):
+                        self.minute_signal_np[-1, signal_counter] = 0
                 counter = counter + 1
+            last_signals = self.minute_signal_np[-1, len(self.generic_columns) :]
+            return self.minute_signals_ia_mixing(last_signals)
+        return np.nan
+
+    def day_signals_ia_mixing(self, signals):
+        nb_nan_signals = np.isnan(signals).sum()
+        print('still '+str(nb_nan_signals)+' not triggered day signals')
+        return np.nanmean(signals)
+
+    def minute_signals_ia_mixing(self, signals):
+        nb_nan_signals = np.isnan(signals).sum()
+        print('still '+str(nb_nan_signals)+' not triggered minute signals')
+        return np.nanmean(signals)
+
 
     def runMinuteSignal(self, me_signal):
         ## idiosyncratic run itself
