@@ -378,7 +378,7 @@ def recompute_perf_returns(signals_df, close_df, transac_cost=True, print_turnov
                 signals_returns_df[sig] = freqly_df.perf_return
     return signals_returns_df
 
-def daily_signal_hourlyzation(close, daily_signal, transaction_cost=True):
+def daily_signal_hourlyzation(close, daily_signal, transaction_cost=True, method = 'interpolate'):
     if not isinstance(close, pd.DataFrame):
         close = pd.DataFrame(close)
     if not isinstance(daily_signal, pd.DataFrame):
@@ -391,7 +391,13 @@ def daily_signal_hourlyzation(close, daily_signal, transaction_cost=True):
     daily_signal = daily_signal.fillna(0)
 
     hourly_signal = daily_signal.asfreq(freq='H')
-    hourly_signal.signal = hourly_signal.signal.interpolate(method='linear')
+    if method == 'interpolate':
+        print('interpolating')
+        hourly_signal['signal'] = hourly_signal['signal'].shift(1)
+        hourly_signal['signal'] = hourly_signal['signal'].interpolate(method='linear')
+    else:
+        print('forward filling')
+        hourly_signal.signal = hourly_signal.signal.ffill()
 
     starting_date = max(hourly_signal.index[0], close.index[0])
     running_date = min(hourly_signal.index[-1], close.index[-1])
